/* -*- Mode: C; indent-tabs-mode: t; c-basic-offset: 8; tab-width: 8 -*-  */
/* common.c
 *
 * Copyright (C) 2019  Giam Teck Choon <choon@choon.net>
 *
 * This program is free software; you can redistribute it and/or
 * modify it under the terms of the GNU General Public License
 * as published by the Free Software Foundation; either version 2
 * of the License, or (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA
 * 02110-1301, USA.
 */

#include <string.h> /* strerror needed */
#include <errno.h>
#include <bglibs/iobuf.h>
#include <bglibs/str.h>

void outmsg(const char *msg)
{
	obuf_putsflush(&outbuf, msg);
}

void outmsgf(const char *format, ...)
{
	va_list ap;
	va_start(ap, format);
	obuf_putfv(&outbuf, format, ap);
	obuf_flush(&outbuf);
	va_end(ap);
}

void errmsg(const char *msg)
{
	obuf_putsflush(&errbuf, msg);
}

void errmsgf(const char *format, ...)
{
	va_list ap;
	va_start(ap, format);
	obuf_putfv(&errbuf, format, ap);
	obuf_flush(&errbuf);
	va_end(ap);
}

void exit_msg(const char *msg, int code, void (*callbackfn)(void))
{
	outmsg(msg);
	callbackfn();
	exit(code);
}

void exit_cb(int code, void (*callbackfn)(void))
{
	callbackfn();
	exit(code);
}
