#ifndef __INTERNAL_COMMON__H__
#define __INTERNAL_COMMON__H__

void outmsg(const char *msg);
void outmsgf(const char *format, ...);
void errmsg(const char *msg);
void errmsgf(const char *format, ...);
void exit_msg(const char *msg, int code, void (*callbackfn)(void));
void exit_cb(int code, void (*callbackfn)(void));

#endif

#ifndef SUCCESS_STOP
#define SUCCESS_STOP 99
#endif

#ifndef SUCCESS_CONTINUE
#define SUCCESS_CONTINUE 0
#endif

#ifndef FAIL_HARD
#define FAIL_HARD 100
#endif

#ifndef FAIL_SOFT
#define FAIL_SOFT 111
#endif

#ifndef SPAMDIRNAME
#define SPAMDIRNAME "Spam"
#endif

#ifndef SPAMVUSERPREF
#define SPAMVUSERPREF "/spamassassin/user_prefs"
#endif

#ifndef CATCH_NE_ONE
#include <string.h>
#include <errno.h>
#define CATCH_NE_ONE(exp, fn) \
	if ((exp) != 1) { \
		errmsgf("{File='}s{' Function='}s{' Line='}d{' (}s{ != 1)\n}", \
			__FILE__, __FUNCTION__, __LINE__, #exp); \
		if (errno) { \
			errmsgf("{errno=}d{ errmsg=}s{\n}", \
				errno, strerror(errno)); \
		} \
		if (#fn) { \
			(fn); \
		} \
	}
#endif
#ifndef CATCH_NE_ZERO
#include <string.h>
#include <errno.h>
#define CATCH_NE_ZERO(exp, fn) \
	if ((exp) != 0) { \
		errmsgf("{File='}s{' Function='}s{' Line='}d{' (}s{ != 0)\n}", \
			__FILE__, __FUNCTION__, __LINE__, #exp); \
		if (errno) { \
			errmsgf("{errno=}d{ errmsg=}s{\n}", \
				errno, strerror(errno)); \
		} \
		if (#fn) { \
			(fn); \
		} \
	}
#endif
#ifndef CATCH_NE
#include <string.h>
#include <errno.h>
#define CATCH_NE(exp, val, fn) \
	if ((exp) != val) { \
		errmsgf("{File='}s{' Function='}s{' Line='}d{'" \
			" (}s{ != }s{)\n}", \
			__FILE__, __FUNCTION__, __LINE__, #exp, #val); \
		if (errno) { \
			errmsgf("{errno=}d{ errmsg=}s{\n}", \
				errno, strerror(errno)); \
		} \
		if (#fn) { \
			(fn); \
		} \
	}
#endif
#ifndef CATCH_EQ
#include <string.h>
#include <errno.h>
#define CATCH_EQ(exp, val, fn) \
	if ((exp) == val) { \
		errmsgf("{File='}s{' Function='}s{' Line='}d{'" \
			" (}s{ == }s{)\n}", \
			__FILE__, __FUNCTION__, __LINE__, #exp, #val); \
		if (errno) { \
			errmsgf("{errno=}d{ errmsg=}s{\n}", \
				errno, strerror(errno)); \
		} \
		if (#fn) { \
			(fn); \
		} \
	}
#endif
