/* -*- Mode: C; indent-tabs-mode: t; c-basic-offset: 8; tab-width: 8 -*-  */
/* 
 * Copyright (C) 2019 by Giam Teck Choon
 *
 * This program is free software; you can redistribute it and/or
 * modify it under the terms of the GNU General Public License
 * as published by the Free Software Foundation; either version 2
 * of the License, or (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA
 * 02110-1301, USA.
 */

/*!
 *  @file is_maildir.c
 *  @date 21 Sep 2019
 *  @author Giam Teck Choon
 *  @brief Function for is_maildir()
 *  @bug No known bugs.
 */

#include <errno.h>
#include <bglibs/str.h>
#include "is_dir.h"

/*!
 *  @brief Test whether path is a valid maildir.
 *  @param path Path to the maildir.
 *  @return On success, 1 is returned. Otherwise, 0 is returned.
 *          On error, -1 is returned, and errno is set appropriately.
 */
int is_maildir(const char *path)
{
	if (is_dir(path)) {
		static str t = {0,0,0};
		if (!str_copy2s(&t, path, "/tmp")) {
			errno = ENOMEM;
			str_free(&t);
			return -1;
		}
		if (!is_dir(t.s)) {
			str_free(&t);
			return 0;
		}
		if (!str_copy2s(&t, path, "/new")) {
			errno = ENOMEM;
			str_free(&t);
			return -1;
		}
		if (!is_dir(t.s)) {
			str_free(&t);
			return 0;
		}
		if (!str_copy2s(&t, path, "/cur")) {
			errno = ENOMEM;
			str_free(&t);
			return -1;
		}
		if (!is_dir(t.s)) {
			str_free(&t);
			return 0;
		}
		str_free(&t);
		return 1;
	}
	return 0;
}
