/* -*- Mode: C; indent-tabs-mode: t; c-basic-offset: 8; tab-width: 8 -*-  */
/* 
 * Copyright (C) 2019 by Giam Teck Choon
 *
 * This program is free software; you can redistribute it and/or
 * modify it under the terms of the GNU General Public License
 * as published by the Free Software Foundation; either version 2
 * of the License, or (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA
 * 02110-1301, USA.
 */

/*!
 *  @file maildirformatname.c
 *  @date 21 Sep 2019
 *  @author Giam Teck Choon
 *  @brief Function for maildirformatname()
 *  @bug No known bugs.
 */

#include <unistd.h>
#include <sys/types.h>
#include <sys/time.h>
#include <errno.h>
#include <bglibs/str.h>

/*!
 *  @brief Generate maildir format file name.
 *  @see http://cr.yp.to/proto/maildir.html
 *  @param s Record generated maildir format file name to struct str s.
 *  @param hostname Hostname string.
 *  @return On success, 0 is returned. On error, -1 is returned, and errno is
 *          set appropriately.
 */
int maildirformatname(str *s, const char *hostname)
{
	struct timeval tv;
	if (gettimeofday(&tv, NULL) != 0) { /* <sys/time.h> */
		return -1;
	}
	if (s->s) {
		if (!str_truncate(s, 0)) {
			errno = ENOMEM;
			return -1;
		}
	}
	/*
	 * getpid() needs <sys/types.h> and <unistd.h>
	 */
	if (!str_copyf(s, "u{.}u{.}u{.}s", tv.tv_sec,
		   tv.tv_usec, getpid(), hostname)) {
		errno = ENOMEM;
		return -1;
	}
	return 0;
}
