/* -*- Mode: C; indent-tabs-mode: t; c-basic-offset: 8; tab-width: 8 -*-  */
/* 
 * Copyright (C) 2019 by Giam Teck Choon
 *
 * This program is free software; you can redistribute it and/or
 * modify it under the terms of the GNU General Public License
 * as published by the Free Software Foundation; either version 2
 * of the License, or (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA
 * 02110-1301, USA.
 */

/*!
 *  @file mkmaildir.c
 *  @date 21 Sep 2019
 *  @author Giam Teck Choon
 *  @brief Function for mkmaildir()
 *  @bug No known bugs.
 */

#include <sys/stat.h>
#include <sys/types.h>
#include <errno.h>
#include <bglibs/str.h>
#include "is_dir.h"

/*!
 *  @brief Create maildir.
 *  @param path Path to the maildir to be created.
 *  @return On success, 0 is returned.
 *          On error, -1 is returned, and errno is set appropriately.
 */
int mkmaildir(const char *path)
{
	if (!is_dir(path)) {
		/*
		 * mkdir needs <sys/stat.h> and <sys/types.h> 
		 */
		if (mkdir(path, 0700) != 0) {
			return -1;
		}
	}
	static str t = {0,0,0};
	if (!str_copy2s(&t, path, "/tmp")) {
		str_free(&t);
		errno = ENOMEM;
		return -1;
	}
	if (!is_dir(t.s)) {
		if (mkdir(t.s, 0700) != 0) {
			str_free(&t);
			return -1;
		}
	}
	if (!str_copy2s(&t, path, "/new")) {
		str_free(&t);
		errno = ENOMEM;
		return -1;
	}
	if (!is_dir(t.s)) {
		if (mkdir(t.s, 0700) != 0) {
			str_free(&t);
			return -1;
		}
	}
	if (!str_copy2s(&t, path, "/cur")) {
		str_free(&t);
		errno = ENOMEM;
		return -1;
	}
	if (!is_dir(t.s)) {
		if (mkdir(t.s, 0700) != 0) {
			str_free(&t);
			return -1;
		}
	}
	str_free(&t);
	return 0;
}
