/* -*- Mode: C; indent-tabs-mode: t; c-basic-offset: 8; tab-width: 8 -*-  */
/* 
 * Copyright (C) 2019 by Giam Teck Choon
 *
 * This program is free software; you can redistribute it and/or
 * modify it under the terms of the GNU General Public License
 * as published by the Free Software Foundation; either version 2
 * of the License, or (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA
 * 02110-1301, USA.
 */

/*!
 *  @file str_hostname.c
 *  @date 21 Sep 2019
 *  @author Giam Teck Choon
 *  @brief Function for str_hostname()
 *  @bug No known bugs.
 */

#include <unistd.h> /* for gethostname() */
#include <errno.h>
#include <bglibs/str.h>

/*!
 *  @brief Get system hostname.
 *
 *  @param s Record hostname string to struct str s.
 *  @return On success, 0 is returned. On error, -1 is returned, and errno
 *          is set appropriately.
 */
int str_hostname(str *s)
{
	char name[512];
	if (gethostname(name, 511) != 0) { /* <unistd.h> */
		return -1;
	}
	if (s->s) {
		if (!str_truncate(s, 0)) {
			errno = ENOMEM;
			return -1;
		}
	}
	if (str_copys(s, name)) {
		return 0;
	}
	errno = ENOMEM;
	return -1;
}
